# Digitalhub-core Library

The Digitalhub-core SDK library is used to manage entities and executions in Digitalhub from Python.
The Digitalhub-core layer is the foundational layer of the Digitalhub Data platform.
It contains the core entities and objects (Artifacts, Projects, Secrets, Functions, Workflows, Task and Runs) and the methods to manage them.

A more detailed description of the library can be found in the [official documentation](https://scc-digitalhub.github.io/docs/) of Digitalhub.
